Type: Package
Package: pxweb
Title: R Interface to PXWEB APIs
Version: 0.17.0
Date: 2024-01-28
Authors@R: c(
    person("Mans", "Magnusson", , "mons.magnusson@gmail.com", role = c("aut", "cre"),
           comment = c(ORCID = "0000-0002-0296-2719")),
    person("Markus", "Kainu", role = "aut"),
    person("Janne", "Huovari", role = "aut"),
    person("Leo", "Lahti", role = "aut",
           comment = c(ORCID = "0000-0001-5537-637X")),
    person("Love", "Hansson", role = "ctb"),
    person("Eydun", "Nielsen", role = "ctb"),
    person("Bo", "Werth", role = "ctb"),
    person("Thomas", "Runarsson", role = "ctb"),
    person("Torbjörn", "Lindquist", role = "ctb"),
    person("Palmar", "Thorsteinsson", role = "ctb"),
    person("Pyry", "Kantanen", role = "ctb"),
    person("Sebastian", "Ankargren", role = "ctb")
  )
Description: Generic interface for the PX-Web/PC-Axis API. The
    PX-Web/PC-Axis API is used by organizations such as Statistics Sweden
    and Statistics Finland to disseminate data. The R package can interact
    with all PX-Web/PC-Axis APIs to fetch information about the data
    hierarchy, extract metadata and extract and parse statistics to R
    data.frame format. PX-Web is a solution to disseminate PC-Axis data
    files in dynamic tables on the web.  Since 2013 PX-Web contains an API
    to disseminate PC-Axis files.
License: BSD_2_clause + file LICENSE
URL: https://github.com/rOpenGov/pxweb/,
        https://ropengov.github.io/pxweb/,
        https://github.com/rOpenGov/pxweb
BugReports: https://github.com/rOpenGov/pxweb/issues
Depends: R (>= 3.5.0)
Imports: checkmate, curl, httr (>= 1.1), jsonlite
Suggests: digest, httptest, knitr, remotes, rmarkdown, testthat (>=
        0.11), xml2
VignetteBuilder: knitr
Encoding: UTF-8
RoxygenNote: 7.2.3
X-schema.org-isPartOf: http://ropengov.org/
X-schema.org-keywords: ropengov
NeedsCompilation: no
Packaged: 2024-01-28 12:57:36 UTC; manma760
Author: Mans Magnusson [aut, cre] (<https://orcid.org/0000-0002-0296-2719>),
  Markus Kainu [aut],
  Janne Huovari [aut],
  Leo Lahti [aut] (<https://orcid.org/0000-0001-5537-637X>),
  Love Hansson [ctb],
  Eydun Nielsen [ctb],
  Bo Werth [ctb],
  Thomas Runarsson [ctb],
  Torbjörn Lindquist [ctb],
  Palmar Thorsteinsson [ctb],
  Pyry Kantanen [ctb],
  Sebastian Ankargren [ctb]
Maintainer: Mans Magnusson <mons.magnusson@gmail.com>
Repository: CRAN
Date/Publication: 2024-01-29 08:50:02 UTC
Built: R 4.6.0; ; 2026-04-26 06:01:12 UTC; unix
