# Generated by roxygen2: do not edit by hand

S3method(as.data.frame,pxweb_data)
S3method(as.data.frame,pxweb_data_comments)
S3method(as.data.frame,pxweb_levels)
S3method(as.data.frame,pxweb_metadata)
S3method(as.matrix,pxweb_data)
S3method(print,pxweb)
S3method(print,pxweb_api_catalogue_entry)
S3method(print,pxweb_data)
S3method(print,pxweb_data_comment)
S3method(print,pxweb_data_comments)
S3method(print,pxweb_database_list)
S3method(print,pxweb_levels)
S3method(print,pxweb_metadata)
S3method(print,pxweb_query)
S3method(pxweb_api_catalogue_entry,list)
S3method(pxweb_as_data_frame,pxweb_data)
S3method(pxweb_as_data_frame,pxweb_data_comment)
S3method(pxweb_as_data_frame,pxweb_data_comments)
S3method(pxweb_as_data_frame,pxweb_levels)
S3method(pxweb_data_comments,pxweb_data)
S3method(pxweb_query,character)
S3method(pxweb_query,json)
S3method(pxweb_query,list)
S3method(pxweb_query,pxweb_explorer)
S3method(pxweb_query,pxweb_query)
S3method(pxweb_query,response)
export(api_catalogue)
export(api_parameters)
export(base_url)
export(checkForLevels)
export(get_pxweb_data)
export(get_pxweb_dims)
export(get_pxweb_levels)
export(get_pxweb_metadata)
export(interactive_pxweb)
export(is.pxweb)
export(is_pxweb_response)
export(pxweb)
export(pxweb_advanced_get)
export(pxweb_api)
export(pxweb_api_catalogue)
export(pxweb_api_catalogue_path)
export(pxweb_as_data_frame)
export(pxweb_cite)
export(pxweb_data_comments)
export(pxweb_get)
export(pxweb_get_data)
export(pxweb_interactive)
export(pxweb_parse_response)
export(pxweb_query)
export(pxweb_query_as_json)
export(pxweb_query_as_rcode)
export(pxweb_test_api)
export(pxweb_validate_query_with_metadata)
export(update_pxweb_apis)
